The Greenland ice sheet mass balance measures the change in ice mass of the Greenland ice sheet. The change in mass is estimated in three principle ways: gravimetric measurements, altimetric measurements and the input-output method. Gravimetric measurements infer mass changes from variations in the Earth's gravitational field as measured by the GRACE and GRACE-FO (Gravity Recovery and Climate Experiment - Follow On) satellites. Altimetric measurements, measured the height of the ice sheet surface, using radar and laser altimeters. Input-output methods, use weather conditions from a numerical weather prediction model, to estimate changes in mass balance at the surface of the ice sheet. These are combined with estimates of mass loss from glaciers around the edge of Greenland and melting on the underside of the glaciers. The IMBIE data set combines over 25 different estimates of Greenland mass balance to get a comprehensive view of the long-term changes.